/* $Id$ */
/**************************************************************************
 *
 *  FILE            vidproxy.c
 *  MODULE OF       vidproxy
 *
 *  DESCRIPTION     
 *
 *  WRITTEN BY      Sverre H. Huseby <sverrehu@ifi.uio.no>
 *
 **************************************************************************/

#include <stdlib.h>
#include <stdio.h>

#include <shhmsg.h>
#include <shhopt.h>
#include <shhnet.h>

#include "shhsched.h"
#include "netcamera.h"
#include "netviewer.h"

/**************************************************************************
 *                                                                        *
 *                       P R I V A T E    D A T A                         *
 *                                                                        *
 **************************************************************************/



/**************************************************************************
 *                                                                        *
 *                   P R I V A T E    F U N C T I O N S                   *
 *                                                                        *
 **************************************************************************/

static void
version(void)
{
    printf(
      "%s " VERSION ", by Sverre H. Huseby "
      "(compiled " COMPILED_DATE " by " COMPILED_BY ")\n",
      msgGetName()
    );
    exit(0);
}

static void
usage(void)
{
    printf(
      "usage: %s [options]\n"
      "\n"
      "  -h, --help               display this help and exit\n"
      "  -c, --camera-port=PORT   set the port number for camera daemon\n"
      "  -p, --port=PORT          set the port number for remote viewers\n"
      "  -V, --version            output version information and exit\n"
      "\n",
      msgGetName()
    );
    exit(0);
}



/**************************************************************************
 *                                                                        *
 *                    P U B L I C    F U N C T I O N S                    *
 *                                                                        *
 **************************************************************************/

int
main(int argc, char *argv[])
{
    optStruct opt[] = {
      /* short long           type        var/func          special       */
        { 'h', "help",        OPT_FLAG,   usage,            OPT_CALLFUNC },
        { 'c', "camera-port", OPT_STRING, netcSetLocalPort, OPT_CALLFUNC },
        { 'p', "port",        OPT_STRING, netvSetLocalPort, OPT_CALLFUNC },
        { 'V', "version",     OPT_FLAG,   version,          OPT_CALLFUNC },
        { 0, 0, OPT_END, 0, 0 }  /* no more options */
    };

    msgSetName(argv[0]);
    snSetErrorHandling(SN_REPORT_ERROR_AND_EXIT, msgFatal);

    optParseOptions(&argc, argv, opt, 0);

    schedInit();
    netcInit();
    netvInit();

    schedLoop();

    netvFinish();
    netcFinish();
    schedFinish();
    return 0;
}
